version
==================================================
**Module**: :mod:`espressodb.management.utilities.version`


.. automodule:: espressodb.management.utilities.version
    :members:
    :special-members:
